@@ -2,7 +2,7 @@
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020,2021,2022,2023 Willem Vermin
+#-# 	      2019,2020,2021,2022,2023,2024 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -20,10 +20,12 @@
 */
 #pragma once
 
-#include <X11/Xlib.h>
-#include "doit.h"
+#include <stdlib.h>
 #include "safe_malloc.h"
 
+#include "doit.h"
+
+#ifndef MAKEMAN
 #define UIDO(_x,_y) \
    if(Flags._x != OldFlags._x) \
 { \
@@ -42,6 +44,7 @@
    OldFlags._x = strdup(Flags._x); \
    Flags.Changes++; \
 }
+#endif
 
 #define DOIT_I(x,d,v) int x;
 #define DOIT_L(x,d,v) unsigned long int x;
@@ -62,4 +65,5 @@ extern FLAGS VintageFlags;
 
 extern int  HandleFlags(int argc, char*argv[]);
 extern void InitFlags(void);
+extern void SetDefaultFlags(void);
 extern void WriteFlags(void);
